@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-03-13'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -14,6 +14,7 @@ has sample_bench => (is=>'rw');
 sub mvp_multivalue_args { qw(sample_bench) }
 
 use Bencher;
+use Data::Dmp;
 use Perinci::Sub::ConvertArgs::Argv qw(convert_args_to_argv);
 use String::ShellQuote;
 
@@ -146,7 +147,7 @@ sub _process_module {
         my $i = -1;
         for my $bench (@$sample_benches) {
             $i++;
-            $self->log_debug(["Running benchmark with args %s", $bench->{args}]);
+            $self->log(["Running benchmark with args %s", $bench->{args}]);
             my $bench_res = Bencher::bencher(
                 action => 'bench',
                 scenario_module => $scenario_name,
@@ -170,7 +171,7 @@ sub _process_module {
         } # for sample_benches
 
         if (@modules && !$scenario->{module_startup}) {
-            $self->log_debug(["Running module_startup benchmark"]);
+            $self->log(["Running module_startup benchmark"]);
             my $bench_res2 = Bencher::bencher(
                 action => 'bench',
                 module_startup => 1,
@@ -250,6 +251,9 @@ sub _process_module {
             }
             if ($p->{cmdline}) {
                 push @pod, "Command line:\n\n", " $p->{cmdline}\n\n";
+            } elsif ($p0->{cmdline_template}) {
+                my $c = $p0->{cmdline_template}; $c = dmp($c) if ref($c) eq 'ARRAY';
+                push @pod, "Command line template:\n\n", " $c\n\n";
             } elsif ($p0->{fcall_template}) {
                 my $val = $p0->{fcall_template}; $val =~ s/^/ /gm;
                 push @pod, "Function call template:\n\n", $val, "\n\n";
@@ -327,7 +331,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.11 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-01-22.
+This document describes version 0.12 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-03-13.
 
 =head1 SYNOPSIS
 
